
clear; 
clc;

%%%%%%%%%%%%%%%%%%%%%% THIS BLOCK CALIBRATES THE MODEL %%%%%%%%%%%%%%%%%%%%
% SIMPLY LOADS PREVIOUS RUN IF AUX.CALIBRATE=0 %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% MOMENTS
moments = struct ( ...
    'jtu_mth', 0.04, ...               % The sum of of the monthly separation rate in 2016 by Alireza and Postel-Vinay
    'Ew', 545, ...                     % The mean weekly wage in Feb 2020 according to the ONS Weekly Earnings (KAB9) series - used by HMT and BoE for inflation reports
    'v_stock' , 794000/66.65/10^6, ... % = 794000 vacancies Sept-Novemeber 2019, Source:  Office for National Statistics - Vacancy Survey 
    'emp' , 0.76, ...                  % Source: Office for National Statistics – Labour Force Survey (16-64 year olds)
    'Eh', 0.38, ...                    % Source: Dingel and Neiman
    'h50' , 0.26,...                   % Source: Dingel and Neiman
    'h9010', 0.88, ...                 % Source: Dingel and Neiman
    'corr_log_w_h', 0.7056,...         % Source: Dingel and Neiman
    'dth_rate_yng',  0.00212, ...      % CDC 
    'dth_rate_old', 0.054,...          % CDC
    'lab_share',  0.5463, ...          % It refers to 2016Q3  Source: https://www.ons.gov.uk/economy/nationalaccounts/uksectoraccounts/adhocs/006610labourshareofgdpandprivatenonfinancialcorporationgrossoperatingsurpluscorporateprofitabilitycurrentpricesquarter1jantomar1997toquarter3julytosept2016
    'hiring_cost', 1.18, ...           % Source: Brown et al (2001) say between 55-118% of monthly salary (use high end as Blatter find much larger for high skilled 10-17 weeks)
    'inf_rate_work' , 0.353, ...       % Source: Santeulalia-llopis et al (2021)
    'reproduction_rate', 2.4);         % Source: Ferguson et al.

%% PARAMETERS
% Demographics
param = struct( ...
    'r' ,  -log(.99)/52, ...                 % Discount rate 
    'chi' , 1/15/52, ...                     % Old death rate
    'eta' , 1/40/52 ...                      % Rate of becoming old
    );

param.psi = (param.eta*param.chi)/(param.eta + param.chi);  %Birth rate 

% Labour market
param.delta = - log(1-moments.jtu_mth)/4;  % Job destruction rate
param.xi = 0.35;                           % Matching elasticity, Turrell, Speigner, Djumalieva,Copple and Thurgood (2018), IV estimate Table 3 
param.beta = 0.34;                         % Bargaining power
param.b_u = 0.65*moments.Ew;               % Unemployment benefits young, OECD 0.65, Hall and Migrom 68%
param.b_re = 0.745*moments.Ew;             % Old dude benefits ONS
param.kappa = 4*.55*moments.Ew;            % Vacancy cost (as a share of mean weekly wage)
param.nu = 0.5;                            % Wage re-negotation rate

% Technology
param.corr = 0.8;
param.mu_x = 5;
param.sigma_x = 1;
param.beta1 =0.5;
param.beta2 = 0.5;

%$$$$$$$$$$$$$$$$$$$$$$$$$
aux = struct( ...
    'steady_state', 1,...   % whether or not initiating model at ss with li=0
    'x_grid', 50,...        % size of productivity grid
    'trim', 1e-2, ...       % trimming of distributions
    'x_lb', 0.5, ...        % lower bound of productiviry distribution 
    'alpha_grid', 50,...
    'inf_grid', 10 ,...
    'us_grid', 10, ...
    'ur_grid', 10, ...
    'max_li', 0.25, ...
    'max_us', 0.4, ...
    'max_ur', 0.2,...   
    'display', 0, ...
    'calibrate',0, ...
    'T',365*5, ...          % number of dts simulated for
    'dt',1/7, ...           % timing of simulation is a week
    'l_ini', 1/66/10^6, ... % initial 'viral load'
    'conv_diff',1e-2, ...   % relative difference required for convergence tolerance
    'update',0.1, ...       % weight of new variable when updating
    'lockdown',0, ...       % whether the model is solved in lockdown
    'death_ini', 1, ...     % start time series when UK hits this number of Covid deaths
    't_period', 24, ...     % number of dts to implement lockdown
    'furlough',0 ...        % indicator if furlough is in place
    );
aux.T = aux.T+aux.t_period;

%% LOAD Parameters of the Labor Model

% if still calibrating
if aux.calibrate==1
    
    % load guesses
    load('final_param.mat')

    % parameters to calibrate
    theta = [param.kappa/moments.Ew;param.corr/(1-param.corr) ...
        ;param.sigma_x;param.beta1;param.beta2;param.beta/(1-param.beta);...
        param.mu_x];
    
    %moments to target
    MOM = [moments.Ew; moments.emp; ...
        moments.Eh;... 
        moments.h9010; moments.corr_log_w_h; moments.lab_share;...
        moments.v_stock];
    
    disc=10; fval0=1000;
    while disc>0
        [theta1 ,fval1]= fminsearch( @(x) min_dist(x, MOM, param,aux), theta, ...
            optimset('display','iter'));
        disc = fval0-fval1;
        theta=theta1;
        fval0 = fval1;
    end

    param.kappa = abs(theta(1))*moments.Ew;
    param.corr = abs(theta(2))/(1+abs(theta(2)));
    param.sigma_x = abs(theta(3));
    param.beta1 = abs(theta(4));
    param.beta2 = abs(theta(5));
    param.beta = abs(theta(6))/(1+abs(theta(6)));
    param.mu_x = theta(7);
    % store parameters
    save('final_param.mat','param')
    
% if already calibrated....    
elseif aux.calibrate==0
    
    % load parameters
    load('final_param.mat','param')
    
end

% Epidemic dynamics 
param.rho_y = 7/10; % ten days
param.rho_o = 7/10; % ten days

param.gamma_y = moments.dth_rate_yng*param.rho_y/(1-moments.dth_rate_yng);                % Death rate (young) 
param.gamma_o = moments.dth_rate_old*(param.rho_o + param.chi)/(1-moments.dth_rate_old);  % Death rate (old) 

e = moments.emp*param.chi/(param.eta+param.chi);
lam0 = moments.reproduction_rate*( (param.chi/(param.chi+param.eta) )*...
    (param.gamma_y + param.rho_y) + ...
    (param.eta/(param.chi+param.eta))*(param.gamma_o + param.rho_o+param.chi) )/...
    (1 + moments.inf_rate_work);
lam1 = lam0*moments.inf_rate_work/e;

R0 = (lam0 + lam1*e)/...
    ( (param.chi/(param.chi+param.eta) )*...
    (param.gamma_y + param.rho_y) + ...
    (param.eta/(param.chi+param.eta))*(param.gamma_o + param.rho_o+param.chi) );

param.lambda_0y = lam0;
param.lambda_o  = lam0;
param.lambda_1y = lam1;

param.Theta = 1;
param.gamma_o=param.gamma_o;
param.gamma_y=param.gamma_y;


%%%%%%%%%%%%%%% COMPUTES THE EMPLOYMENT AND INFECTION RISK %%%%%%%%%%

aux.risk = 1;   

% No Lockdown case
param.pi    = 0;
param.alpha = 1;
aux.t_period = aux.T + 1; % makes sure lockdown never implemented
[~,lf_risk] = full_model_risk([], moments, param,aux); %first input determines duration of lockdown

% Lockdown, no furlough sceme 
Lambda_grid = [1/4.3; 1/8.7; 1/13; 1/17.4; 1/21.7; 1/26; 1/52; 1/52/1.5; 1/52/2]; %3 months, 6 months, one year, 18 month, 2 years
aux.t_period = 24;
param.pi = 0.15;
param.alpha = 1;

[~,lck_3_risk] = full_model_risk(Lambda_grid(3),moments, param,aux); 
[~,lck_6_risk] = full_model_risk(Lambda_grid(6),moments, param,aux);

% Lockdown, with furlough sceme 
aux.furlough = 1;
param.furlough = 0.80;
param.furlough_cap = 462.70; 

[~,lck_f_3_risk] = full_model_risk(Lambda_grid(3),moments, param,aux); 
[~,lck_f_6_risk] = full_model_risk(Lambda_grid(6),moments, param,aux);

% Store 
save('final_model_risk.mat','lf_risk','lck_3_risk','lck_6_risk','lck_f_3_risk','lck_f_6_risk')


















